@@ -1,24 +1,36 @@
 package YAML::Tiny;
 
 use strict;
+
+# UTF Support?
+sub HAVE_UTF8 () { $] >= 5.007003 }
 BEGIN {
+	if ( HAVE_UTF8 ) {
+		# The string eval helps hide this from Test::MinimumVersion
+		eval "require utf8;";
+		die "Failed to load UTF-8 support" if $@;
+	}
+
+	# Class structure
 	require 5.004;
 	require Exporter;
-	$YAML::Tiny::VERSION   = '1.34_01';
-	$YAML::Tiny::errstr    = '';
+	require Carp;
+	$YAML::Tiny::VERSION   = '1.45_02';
+	$YAML::Tiny::VERSION   = eval $YAML::Tiny::VERSION;
 	@YAML::Tiny::ISA       = qw{ Exporter  };
-	@YAML::Tiny::EXPORT = qw{
-		Load Dump
-	};
-	@YAML::Tiny::EXPORT_OK = qw{
-		LoadFile DumpFile
-		freeze   thaw
-	};
+	@YAML::Tiny::EXPORT    = qw{ Load Dump };
+	@YAML::Tiny::EXPORT_OK = qw{ LoadFile DumpFile freeze thaw };
+
+	# Error storage
+	$YAML::Tiny::errstr    = '';
 }
 
-my $ESCAPE_CHAR = '[\\x00-\\x08\\x0b-\\x0d\\x0e-\\x1f\"\n]';
+# The character class of all characters we need to escape
+# NOTE: Inlined, since it's only used once
+# my $RE_ESCAPE = '[\\x00-\\x08\\x0b-\\x0d\\x0e-\\x1f\"\n]';
 
-# Escapes for unprintable characters
+# Printed form of the unprintable characters in the lowest range
+# of ASCII characters, listed by ASCII ordinal position.
 my @UNPRINTABLE = qw(
 	z    x01  x02  x03  x04  x05  x06  a
 	x08  t    n    v    f    r    x0e  x0f
@@ -33,6 +45,21 @@ my %UNESCAPES = (
 	r => "\x0d", e => "\x1b", '\\' => '\\',
 );
 
+# Special magic boolean words
+my %QUOTE = map { $_ => 1 } qw{
+	null Null NULL
+	y Y yes Yes YES n N no No NO
+	true True TRUE false False FALSE
+	on On ON off Off OFF
+};
+
+
+
+
+
+#####################################################################
+# Implementation
+
 # Create an empty YAML::Tiny object
 sub new {
 	my $class = shift;
@@ -53,11 +80,11 @@ sub read {
 	local $/ = undef;
 	local *CFG;
 	unless ( open(CFG, $file) ) {
-		return $class->_error( "Failed to open file '$file': $!" );
+		return $class->_error("Failed to open file '$file': $!");
 	}
 	my $contents = <CFG>;
 	unless ( close(CFG) ) {
-		return $class->_error( "Failed to close file '$file': $!" );
+		return $class->_error("Failed to close file '$file': $!");
 	}
 
 	$class->read_string( $contents );
@@ -65,60 +92,90 @@ sub read {
 
 # Create an object from a string
 sub read_string {
-	my $class = ref $_[0] ? ref shift : shift;
-	my $self  = bless [], $class;
-
-	# Handle special cases
-	return undef unless defined $_[0];
-	return $self unless length $_[0];
-	unless ( $_[0] =~ /[\012\015]+$/ ) {
-		return $class->_error("Stream does not end with newline character");
-	}
-
-	# Split the file into lines
-	my @lines = grep { ! /^\s*(?:\#.*)?$/ }
-	            split /(?:\015{1,2}\012|\015|\012)/, shift;
-
-	# Strip the initial YAML header
-	@lines and $lines[0] =~ /^\%YAML[: ][\d\.]+.*$/ and shift @lines;
-
-	# A nibbling parser
-	while ( @lines ) {
-		# Do we have a document header?
-		if ( $lines[0] =~ /^---\s*(?:(.+)\s*)?$/ ) {
-			# Handle scalar documents
-			shift @lines;
-			if ( defined $1 and $1 !~ /^(?:\#.+|\%YAML[: ][\d\.]+)$/ ) {
-				push @$self, $self->_read_scalar( "$1", [ undef ], \@lines );
-				next;
-			}
+	my $class  = ref $_[0] ? ref shift : shift;
+	my $self   = bless [], $class;
+	my $string = $_[0];
+	eval {
+		unless ( defined $string ) {
+			die \"Did not provide a string to load";
 		}
 
-		if ( ! @lines or $lines[0] =~ /^(?:---|\.\.\.)/ ) {
-			# A naked document
-			push @$self, undef;
-			while ( @lines and $lines[0] !~ /^---/ ) {
-				shift @lines;
-			}
-
-		} elsif ( $lines[0] =~ /^\s*\-/ ) {
-			# An array at the root
-			my $document = [ ];
-			push @$self, $document;
-			$self->_read_array( $document, [ 0 ], \@lines );
-
-		} elsif ( $lines[0] =~ /^(\s*)\S/ ) {
-			# A hash at the root
-			my $document = { };
-			push @$self, $document;
-			$self->_read_hash( $document, [ length($1) ], \@lines );
-
+		# Byte order marks
+		# NOTE: Keeping this here to educate maintainers
+		# my %BOM = (
+		#     "\357\273\277" => 'UTF-8',
+		#     "\376\377"     => 'UTF-16BE',
+		#     "\377\376"     => 'UTF-16LE',
+		#     "\377\376\0\0" => 'UTF-32LE'
+		#     "\0\0\376\377" => 'UTF-32BE',
+		# );
+		if ( $string =~ /^(?:\376\377|\377\376|\377\376\0\0|\0\0\376\377)/ ) {
+			die \"Stream has a non UTF-8 BOM";
 		} else {
-			die "YAML::Tiny does not support the line '$lines[0]'";
+			# Strip UTF-8 bom if found, we'll just ignore it
+			$string =~ s/^\357\273\277//;
 		}
+
+		# Try to decode as utf8
+		utf8::decode($string) if HAVE_UTF8;
+
+		# Check for some special cases
+		return $self unless length $string;
+		unless ( $string =~ /[\012\015]+\z/ ) {
+			die \"Stream does not end with newline character";
+		}
+
+		# Split the file into lines
+		my @lines = grep { ! /^\s*(?:\#.*)?\z/ }
+			    split /(?:\015{1,2}\012|\015|\012)/, $string;
+
+		# Strip the initial YAML header
+		@lines and $lines[0] =~ /^\%YAML[: ][\d\.]+.*\z/ and shift @lines;
+
+		# A nibbling parser
+		while ( @lines ) {
+			# Do we have a document header?
+			if ( $lines[0] =~ /^---\s*(?:(.+)\s*)?\z/ ) {
+				# Handle scalar documents
+				shift @lines;
+				if ( defined $1 and $1 !~ /^(?:\#.+|\%YAML[: ][\d\.]+)\z/ ) {
+					push @$self, $self->_read_scalar( "$1", [ undef ], \@lines );
+					next;
+				}
+			}
+
+			if ( ! @lines or $lines[0] =~ /^(?:---|\.\.\.)/ ) {
+				# A naked document
+				push @$self, undef;
+				while ( @lines and $lines[0] !~ /^---/ ) {
+					shift @lines;
+				}
+
+			} elsif ( $lines[0] =~ /^\s*\-/ ) {
+				# An array at the root
+				my $document = [ ];
+				push @$self, $document;
+				$self->_read_array( $document, [ 0 ], \@lines );
+
+			} elsif ( $lines[0] =~ /^(\s*)\S/ ) {
+				# A hash at the root
+				my $document = { };
+				push @$self, $document;
+				$self->_read_hash( $document, [ length($1) ], \@lines );
+
+			} else {
+				die \"YAML::Tiny failed to classify the line '$lines[0]'";
+			}
+		}
+	};
+	if ( ref $@ eq 'SCALAR' ) {
+		return $self->_error(${$@});
+	} elsif ( $@ ) {
+		require Carp;
+		Carp::croak($@);
 	}
 
-	$self;
+	return $self;
 }
 
 # Deparse a scalar string to the actual scalar
@@ -126,41 +183,61 @@ sub _read_scalar {
 	my ($self, $string, $indent, $lines) = @_;
 
 	# Trim trailing whitespace
-	$string =~ s/\s*$//;
+	$string =~ s/\s*\z//;
 
 	# Explitic null/undef
 	return undef if $string eq '~';
 
-	# Quotes
-	if ( $string =~ /^\'(.*?)\'$/ ) {
+	# Single quote
+	if ( $string =~ /^\'(.*?)\'(?:\s+\#.*)?\z/ ) {
 		return '' unless defined $1;
-		my $rv = $1;
-		$rv =~ s/\'\'/\'/g;
-		return $rv;
+		$string = $1;
+		$string =~ s/\'\'/\'/g;
+		return $string;
 	}
-	if ( $string =~ /^\"((?:\\.|[^\"])*)\"$/ ) {
-		my $str = $1;
-		$str =~ s/\\"/"/g;
-		$str =~ s/\\([never\\fartz]|x([0-9a-fA-F]{2}))/(length($1)>1)?pack("H2",$2):$UNESCAPES{$1}/gex;
-		return $str;
+
+	# Double quote.
+	# The commented out form is simpler, but overloaded the Perl regex
+	# engine due to recursion and backtracking problems on strings
+	# larger than 32,000ish characters. Keep it for reference purposes.
+	# if ( $string =~ /^\"((?:\\.|[^\"])*)\"\z/ ) {
+	if ( $string =~ /^\"([^\\"]*(?:\\.[^\\"]*)*)\"(?:\s+\#.*)?\z/ ) {
+		# Reusing the variable is a little ugly,
+		# but avoids a new variable and a string copy.
+		$string = $1;
+		$string =~ s/\\"/"/g;
+		$string =~ s/\\([never\\fartz]|x([0-9a-fA-F]{2}))/(length($1)>1)?pack("H2",$2):$UNESCAPES{$1}/gex;
+		return $string;
 	}
 
 	# Special cases
-	die "Unsupported YAML feature" if $string =~ /^['"!&]/;
-	return {} if $string eq '{}';
-	return [] if $string eq '[]';
+	if ( $string =~ /^[\'\"!&]/ ) {
+		die \"YAML::Tiny does not support a feature in line '$string'";
+	}
+	return {} if $string =~ /^{}(?:\s+\#.*)?\z/;
+	return [] if $string =~ /^\[\](?:\s+\#.*)?\z/;
 
 	# Regular unquoted string
-	return $string unless $string =~ /^[>|]/;
+	if ( $string !~ /^[>|]/ ) {
+		if (
+			$string =~ /^(?:-(?:\s|$)|[\@\%\`])/
+			or
+			$string =~ /:(?:\s|$)/
+		) {
+			die \"YAML::Tiny found illegal characters in plain scalar: '$string'";
+		}
+		$string =~ s/\s+#.*\z//;
+		return $string;
+	}
 
 	# Error
-	die "Multi-line scalar content missing" unless @$lines;
+	die \"YAML::Tiny failed to find multi-line scalar content" unless @$lines;
 
 	# Check the indent depth
-	$lines->[0] =~ /^(\s*)/;
+	$lines->[0]   =~ /^(\s*)/;
 	$indent->[-1] = length("$1");
 	if ( defined $indent->[-2] and $indent->[-1] <= $indent->[-2] ) {
-		die "Illegal line indenting";
+		die \"YAML::Tiny found bad indenting in line '$lines->[0]'";
 	}
 
 	# Pull the lines
@@ -172,7 +249,7 @@ sub _read_scalar {
 	}
 
 	my $j = (substr($string, 0, 1) eq '>') ? ' ' : "\n";
-	my $t = (substr($string, 1, 1) eq '-') ? '' : "\n";
+	my $t = (substr($string, 1, 1) eq '-') ? ''  : "\n";
 	return join( $j, @multiline ) . $t;
 }
 
@@ -194,7 +271,7 @@ sub _read_array {
 		if ( length($1) < $indent->[-1] ) {
 			return 1;
 		} elsif ( length($1) > $indent->[-1] ) {
-			die "Hash line over-indented";
+			die \"YAML::Tiny found bad indenting in line '$lines->[0]'";
 		}
 
 		if ( $lines->[0] =~ /^(\s*\-\s+)[^\'\"]\S*\s*:(?:\s+|$)/ ) {
@@ -204,12 +281,12 @@ sub _read_array {
 			push @$array, { };
 			$self->_read_hash( $array->[-1], [ @$indent, $indent2 ], $lines );
 
-		} elsif ( $lines->[0] =~ /^\s*\-(\s*)(.+?)\s*$/ ) {
+		} elsif ( $lines->[0] =~ /^\s*\-(\s*)(.+?)\s*\z/ ) {
 			# Array entry with a value
 			shift @$lines;
 			push @$array, $self->_read_scalar( "$2", [ @$indent, undef ], $lines );
 
-		} elsif ( $lines->[0] =~ /^\s*\-\s*$/ ) {
+		} elsif ( $lines->[0] =~ /^\s*\-\s*\z/ ) {
 			shift @$lines;
 			unless ( @$lines ) {
 				push @$array, undef;
@@ -231,11 +308,21 @@ sub _read_array {
 				$self->_read_hash( $array->[-1], [ @$indent, length("$1") ], $lines );
 
 			} else {
-				die "YAML::Tiny does not support the line '$lines->[0]'";
+				die \"YAML::Tiny failed to classify line '$lines->[0]'";
 			}
 
+		} elsif ( defined $indent->[-2] and $indent->[-1] == $indent->[-2] ) {
+			# This is probably a structure like the following...
+			# ---
+			# foo:
+			# - list
+			# bar: value
+			#
+			# ... so lets return and let the hash parser handle it
+			return 1;
+
 		} else {
-			die "YAML::Tiny does not support the line '$lines->[0]'";
+			die \"YAML::Tiny failed to classify line '$lines->[0]'";
 		}
 	}
 
@@ -260,13 +347,15 @@ sub _read_hash {
 		if ( length($1) < $indent->[-1] ) {
 			return 1;
 		} elsif ( length($1) > $indent->[-1] ) {
-			die "Hash line over-indented";
+			die \"YAML::Tiny found bad indenting in line '$lines->[0]'";
 		}
 
 		# Get the key
-		unless ( $lines->[0] =~ s/^\s*([^\'\" ][^\n]*?)\s*:(\s+|$)// ) {
-			die "Unsupported YAML feature" if $lines->[0] =~ /^\s*[?'"]/;
-			die "Bad or unsupported hash line";
+		unless ( $lines->[0] =~ s/^\s*([^\'\" ][^\n]*?)\s*:(\s+(?:\#.*)?|$)// ) {
+			if ( $lines->[0] =~ /^\s*[?\'\"]/ ) {
+				die \"YAML::Tiny does not support a feature in line '$lines->[0]'";
+			}
+			die \"YAML::Tiny failed to classify line '$lines->[0]'";
 		}
 		my $key = $1;
 
@@ -303,9 +392,7 @@ sub _read_hash {
 # Save an object to a file
 sub write {
 	my $self = shift;
-	my $file = shift or return $self->_error(
-		'No file name provided'
-		);
+	my $file = shift or return $self->_error('No file name provided');
 
 	# Write it to the file
 	open( CFG, '>' . $file ) or return $self->_error(
@@ -361,20 +448,20 @@ sub write_string {
 }
 
 sub _write_scalar {
-	my $str = $_[1];
-	return '~'  unless defined $str;
-	if ( $str =~ /$ESCAPE_CHAR/ ) {
-		$str =~ s/\\/\\\\/g;
-		$str =~ s/"/\\"/g;
-		$str =~ s/\n/\\n/g;
-		$str =~ s/([\x00-\x1f])/\\$UNPRINTABLE[ord($1)]/g;
-		return qq{"$str"};
+	my $string = $_[1];
+	return '~'  unless defined $string;
+	return "''" unless length  $string;
+	if ( $string =~ /[\x00-\x08\x0b-\x0d\x0e-\x1f\"\'\n]/ ) {
+		$string =~ s/\\/\\\\/g;
+		$string =~ s/"/\\"/g;
+		$string =~ s/\n/\\n/g;
+		$string =~ s/([\x00-\x1f])/\\$UNPRINTABLE[ord($1)]/g;
+		return qq|"$string"|;
 	}
-	if ( length($str) == 0 or $str =~ /(?:^\W|\s)/ ) {
-		$str =~ s/\'/\'\'/;
-		return "'$str'";
+	if ( $string =~ /(?:^\W|\s)/ or $QUOTE{$string} ) {
+		return "'$string'";
 	}
-	return $str;
+	return $string;
 }
 
 sub _write_array {
@@ -479,8 +566,10 @@ sub Dump {
 }
 
 sub Load {
-	my $self = YAML::Tiny->read_string(@_)
-		or Carp::croak("Failed to load YAML document from string");
+	my $self = YAML::Tiny->read_string(@_);
+	unless ( $self ) {
+		Carp::croak("Failed to load YAML document from string");
+	}
 	if ( wantarray ) {
 		return @$self;
 	} else {
@@ -500,12 +589,14 @@ sub DumpFile {
 }
 
 sub LoadFile {
-	my $self = YAML::Tiny->read($_[0])
-		or Carp::croak("Failed to load YAML document from '" . ($_[0] || '') . "'");
+	my $self = YAML::Tiny->read($_[0]);
+	unless ( $self ) {
+		Carp::croak("Failed to load YAML document from '" . ($_[0] || '') . "'");
+	}
 	if ( wantarray ) {
 		return @$self;
 	} else {
-		# To match YAML.pm, return the last document
+		# Return only the last document to match YAML.pm, 
 		return $self->[-1];
 	}
 }
@@ -520,13 +611,13 @@ sub LoadFile {
 BEGIN {
 	eval {
 		require Scalar::Util;
+		*refaddr = *Scalar::Util::refaddr;
 	};
-	if ( $@ ) {
-		# Failed to load Scalar::Util
-		eval <<'END_PERL';
+	eval <<'END_PERL' if $@;
+# Failed to load Scalar::Util	
 sub refaddr {
 	my $pkg = ref($_[0]) or return undef;
-	if (!!UNIVERSAL::can($_[0], 'can')) {
+	if ( !! UNIVERSAL::can($_[0], 'can') ) {
 		bless $_[0], 'Scalar::Util::Fake';
 	} else {
 		$pkg = undef;
@@ -537,9 +628,7 @@ sub refaddr {
 	$i;
 }
 END_PERL
-	} else {
-		Scalar::Util->import('refaddr');
-	}
+
 }
 
 1;
@@ -559,15 +648,19 @@ functionality of XML, except with flexibility and choice, which makes it
 easier to read, but with a formal specification that is more complex than
 XML.
 
-The original pure-Perl implementation L<YAML> costs just over 4 megabytes of
-memory to load. Just like with Windows .ini files (3 meg to load) and CSS
-(3.5 meg to load) the situation is just asking for a B<YAML::Tiny> module, an
-incomplete but correct and usable subset of the functionality, in as little
-code as possible.
+The original pure-Perl implementation L<YAML> costs just over 4 megabytes
+of memory to load. Just like with Windows .ini files (3 meg to load) and
+CSS (3.5 meg to load) the situation is just asking for a B<YAML::Tiny>
+module, an incomplete but correct and usable subset of the functionality,
+in as little code as possible.
 
-Like the other C<::Tiny> modules, YAML::Tiny will have no non-core
-dependencies, not require a compiler, and be back-compatible to at least
-perl 5.005_03, and ideally 5.004.
+Like the other C<::Tiny> modules, YAML::Tiny has no non-core dependencies,
+does not require a compiler to install, is back-compatible to Perl 5.004,
+and can be inlined into other modules if needed.
+
+In exchange for this adding this extreme flexibility, it provides support
+for only a limited subset of YAML. But the subset supported contains most
+of the features for the more common usese of YAML.
 
 =head1 SYNOPSIS
 
@@ -603,7 +696,7 @@ perl 5.005_03, and ideally 5.004.
     # Changing data
     $yaml->[0]->{newsection} = { this => 'that' }; # Add a section
     $yaml->[0]->{section}->{Foo} = 'Not Bar!';     # Change a value
-    delete $yaml->[0]->{section};                  # Delete a value or section
+    delete $yaml->[0]->{section};                  # Delete a value
     
     # Add an entire document
     $yaml->[1] = [ 'foo', 'bar', 'baz' ];
@@ -639,45 +732,47 @@ easily-embeddable module is extremely attractive.
 
 Features will only be added if they are human readable, and can be written
 in a few lines of code. Please don't be offended if your request is
-refused. Someone has to draw the line, and for YAML::Tiny that someone is me.
+refused. Someone has to draw the line, and for YAML::Tiny that someone
+is me.
 
 If you need something with more power move up to L<YAML> (4 megabytes of
 memory overhead) or L<YAML::Syck> (275k, but requires libsyck and a C
 compiler).
 
-To restate, L<YAML::Tiny> does B<not> preserve your comments, whitespace, or
-the order of your YAML data. But it should round-trip from Perl structure
-to file and back again just fine.
+To restate, L<YAML::Tiny> does B<not> preserve your comments, whitespace,
+or the order of your YAML data. But it should round-trip from Perl
+structure to file and back again just fine.
 
 =head1 YAML TINY SPECIFICATION
 
 This section of the documentation provides a specification for "YAML Tiny",
 a subset of the YAML specification.
 
-It is based on and described comparatively to the YAML 1.1  Working Draft
+It is based on and described comparatively to the YAML 1.1 Working Draft
 2004-12-28 specification, located at L<http://yaml.org/spec/current.html>.
 
 Terminology and chapter numbers are based on that specification.
 
 =head2 1. Introduction and Goals
 
-The purpose of the YAML Tiny specification is to describe a useful subset of
-the YAML specification that can be used for typical document-oriented
-uses such as configuration files and simple data structure dumps.
+The purpose of the YAML Tiny specification is to describe a useful subset
+of the YAML specification that can be used for typical document-oriented
+use cases such as configuration files and simple data structure dumps.
 
 Many specification elements that add flexibility or extensibility are
 intentionally removed, as is support for complex datastructures, class
 and object-orientation.
 
-In general, YAML Tiny targets only those data structures available in
-JSON, with the additional limitation that only simple keys are supported.
+In general, the YAML Tiny language targets only those data structures
+available in JSON, with the additional limitation that only simple keys
+are supported.
 
 As a result, all possible YAML Tiny documents should be able to be
 transformed into an equivalent JSON document, although the reverse is
 not necesarily true (but will be true in simple cases).
 
 As a result of these simplifications the YAML Tiny specification should
-be implementable in a relatively small amount of code in any language
+be implementable in a (relatively) small amount of code in any language
 that supports Perl Compatible Regular Expressions (PCRE).
 
 =head2 2. Introduction
@@ -695,7 +790,20 @@ Both line and inline comments are supported.
 Scalars are supported via the plain style, single quote and double quote,
 as well as literal-style and folded-style multi-line scalars.
 
-The use of tags is not supported.
+The use of explicit tags is not supported.
+
+The use of "null" type scalars is supported via the ~ character.
+
+The use of "bool" type scalars is not supported.
+
+However, serializer implementations should take care to explicitly escape
+strings that match a "bool" keyword in the following set to prevent other
+implementations that do support "bool" accidentally reading a string as a
+boolean
+
+  y|Y|yes|Yes|YES|n|N|no|No|NO
+  |true|True|TRUE|false|False|FALSE
+  |on|On|ON|off|Off|OFF
 
 The use of anchors and aliases is not supported.
 
@@ -719,7 +827,7 @@ Because anchors and aliases are not supported, the resulting representation
 graph is thus directed but (unlike the main YAML specification) B<acyclic>.
 
 Circular references/pointers are not possible, and any YAML Tiny serializer
-detecting a circulars should error with an appropriate message.
+detecting a circular reference should error with an appropriate message.
 
 B<Presentation Stream>
 
@@ -889,7 +997,7 @@ Support for nodes optional anchor and tag properties are B<not> required.
 
 Support for node anchors is B<not> required.
 
-Supprot for node tags is B<not> required.
+Support for node tags is B<not> required.
 
 Support for alias nodes is B<not> required.
 
@@ -947,8 +1055,8 @@ The constructor C<new> creates and returns an empty C<YAML::Tiny> object.
 
 =head2 read $filename
 
-The C<read> constructor reads a YAML file, and returns a new
-C<YAML::Tiny> object containing the contents of the file. 
+The C<read> constructor reads a YAML file from a file name,
+and returns a new C<YAML::Tiny> object containing the parsed content.
 
 Returns the object on success, or C<undef> on error.
 
@@ -960,9 +1068,10 @@ the C<$!> variable.
 
 =head2 read_string $string;
 
-The C<read_string> method takes as argument the contents of a YAML file
-(a YAML document) as a string and returns the C<YAML::Tiny> object for
-it.
+The C<read> constructor reads a YAML file from a file name,
+and returns a new C<YAML::Tiny> object containing the parsed content.
+
+Returns the object on success, or C<undef> on error.
 
 =head2 write $filename
 
@@ -991,9 +1100,11 @@ to explicitly import the functions.
 
   my $string = Dump(list-of-Perl-data-structures);
 
-Turn Perl data into YAML. This function works very much like Data::Dumper::Dumper().
+Turn Perl data into YAML. This function works very much like
+Data::Dumper::Dumper().
 
-It takes a list of Perl data strucures and dumps them into a serialized form.
+It takes a list of Perl data strucures and dumps them into a serialized
+form.
 
 It returns a string containing the YAML stream.
 
@@ -1049,7 +1160,7 @@ L<http://use.perl.org/~Alias/journal/29427>, L<http://ali.as/>
 
 =head1 COPYRIGHT
 
-Copyright 2006 - 2008 Adam Kennedy.
+Copyright 2006 - 2010 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
